@@ -7,13 +7,16 @@ do
 done
 montage 	-pointsize 150 \
 -label "none"		tmp/graphics_vmode_none.xpm 	\
--label "low_ansi"	tmp/graphics_vmode_low_ansi.xpm \
 -label "monochrome"	tmp/graphics_vmode_monochrome.xpm \
+-label "low_ansi"	tmp/graphics_vmode_low_ansi.xpm \
+-label "low_ansi2"	tmp/graphics_vmode_low_ansi2.xpm \
 -label "high_ansi"	tmp/graphics_vmode_high_ansi.xpm \
--label "sixel"		tmp/graphics_vmode_sixel.xpm \
 -label "high_ansi2"	tmp/graphics_vmode_high_ansi2.xpm \
--geometry 2007x1685+10+20 -tile 2x3 -strip -colors 512 tmp/graphics_modes.png
+-label "utf"		tmp/graphics_vmode_utf.xpm \
+-label "sixel"		tmp/graphics_vmode_sixel.xpm \
+-geometry 2007x1685+150+20 -tile 2x4 -strip -colors 512 tmp/graphics_modes.png
 convert tmp/graphics_modes.png -strip graphics_modes.png
+convert graphics_modes.png -scale 810x1123 -quality 60 graphics_modes.jpg
 
 montage -pointsize 150 \
 -label "1024x768" graphics_vmode_sixel1024x768.png \
